@@ -26,9 +26,12 @@
 ## Author: Andrew Hooker
 
 blockfinal <- function(fn,fmf,dmf,groupsize,ni,xt,x,a,model_switch,bpop,d,docc,sigma,poped.db,
-                         opt_xt=poped.db$settings$optsw[2],opt_a=poped.db$settings$optsw[4],opt_x=poped.db$settings$optsw[3],
-                         fmf_init=NULL,dmf_init=NULL,param_cvs_init=NULL,
-                         compute_inv=TRUE,out_file=NULL,trflag=TRUE,footer_flag=TRUE,...){
+                       opt_xt=poped.db$settings$optsw[2],opt_a=poped.db$settings$optsw[4],opt_x=poped.db$settings$optsw[3],
+                       fmf_init=NULL,dmf_init=NULL,param_cvs_init=NULL,
+                       compute_inv=TRUE,out_file=NULL,trflag=TRUE,footer_flag=TRUE,
+                       run_time = NULL,
+                       ...){
+  time_value <- NULL
   
   if(!trflag) return(invisible() ) 
   if(footer_flag){
@@ -40,8 +43,8 @@ blockfinal <- function(fn,fmf,dmf,groupsize,ni,xt,x,a,model_switch,bpop,d,docc,s
     fprintf(fn,'===============================================================================\nFINAL RESULTS\n')
     if(fn!="") fprintf('===============================================================================\nFINAL RESULTS\n')
     
-    time_value <- NULL
-    if(exists(".poped_total_time", envir=.PopedNamespaceEnv)) time_value = toc(echo=FALSE,name=".poped_total_time")
+    time_value <- run_time
+    if(is.null(time_value) & exists(".poped_total_time", envir=.PopedNamespaceEnv)) time_value = toc(echo=FALSE,name=".poped_total_time")
     if((opt_xt==TRUE)){
       print_xt(xt,ni,model_switch,fn,head_txt="Optimized Sampling Schedule\n")
       if(fn!="") print_xt(xt,ni,model_switch,head_txt="\nOptimized Sampling Schedule\n")
@@ -116,24 +119,46 @@ blockfinal <- function(fn,fmf,dmf,groupsize,ni,xt,x,a,model_switch,bpop,d,docc,s
     output <- get_unfixed_params(poped.db)
     npar <- length(output$all)
     
-    if(fn!="" || trflag>1) fprintf(fn,'\nEfficiency criterion [usually defined as OFV^(1/npar)]  = %g\n',
+    if(fn!="" || trflag>1) fprintf(fn,'\nEfficiency criterion [usually defined as det(FIM)^(1/npar)]  = %g\n',
             ofv_criterion(dmf,npar,poped.db))
     
-    fprintf(fn,'\nEfficiency [typically: (OFV_final/OFV_initial)^(1/npar)]: %g\n',
-            ofv_criterion(dmf,npar,poped.db)/ofv_criterion(dmf_init,npar,poped.db))
-    if(fn!=""){
-      fprintf('\nEfficiency [typically: (OFV_final/OFV_initial)^(1/npar)]: %g\n',
-              ofv_criterion(dmf,npar,poped.db)/ofv_criterion(dmf_init,npar,poped.db))
+    # fprintf(fn,'\nEfficiency [typically: (OFV_final/OFV_initial)^(1/npar)]: %g\n',
+    #         ofv_criterion(dmf,npar,poped.db)/ofv_criterion(dmf_init,npar,poped.db))
+    # if(fn!=""){
+    #   fprintf('\nEfficiency [typically: (OFV_final/OFV_initial)^(1/npar)]: %g\n',
+    #           ofv_criterion(dmf,npar,poped.db)/ofv_criterion(dmf_init,npar,poped.db))
+    # }
+    
+    if(!is.null(dmf_init)){
+      eff <- efficiency(dmf_init, dmf, poped.db)
+      fprintf(fn,"\nEfficiency: \n  (%s) = %.5g\n",attr(eff,"description"),eff,both=TRUE)
     }
+    # fprintf(fn,'\nEfficiency (Final/Initial): %0.5g\n',
+    #         ofv_criterion(dmf,npar,poped.db)/ofv_criterion(dmf_init,npar,poped.db),both=TRUE)
+    # 
     #fprintf(fn,'\nEfficiency criterion: det(FIM)^(1/npar) = %g\n',dmf^(1/length(params)))
     #fprintf(fn,'\nEfficiency (final_design/initial_design): %g\n',(dmf^(1/length(params)))/(dmf_init^(1/length(params))))
     #if(fn!="") fprintf('\nEfficiency (final_design/initial_design): %g\n',(dmf^(1/length(params)))/(dmf_init^(1/length(params))))
     
+    # if((poped.db$settings$ofv_calc_type==4) && !is.null(fmf_init) && !is.null(fmf) ){#D-Optimal Design
+    #   fprintf(fn,'\nD-Efficiency [(det(FIM_final)/det(FIM_initial))^(1/npar)]: %g\n',
+    #           (det(fmf)/det(fmf_init))^(1/npar))
+    #   if(fn!=""){
+    #     fprintf(fn,'\nD-Efficiency [(det(FIM_final)/det(FIM_initial))^(1/npar)]: %g\n',
+    #             (det(fmf)/det(fmf_init))^(1/npar))
+    #   }
+    # }
+    # 
+    
     if(is.null(param_cvs_init) && !is.null(fmf_init) && is.matrix(fmf_init) && compute_inv){
+      if(is.finite(dmf_init)) {
+        
+      
       param_vars_init=diag_matlab(inv(fmf_init))
       returnArgs <-  get_cv(param_vars_init,bpop,d,docc,sigma,poped.db) 
       params_init <- returnArgs[[1]]
       param_cvs_init <- returnArgs[[2]]
+      }
     }
     
     if(compute_inv){
@@ -146,14 +171,13 @@ blockfinal <- function(fn,fmf,dmf,groupsize,ni,xt,x,a,model_switch,bpop,d,docc,s
       if(fn!="") capture.output(print(df,digits=3, print.gap=3,row.names=F),file=fn)
     }
     
-    #if(!is.null(time_value)){
-    fprintf(fn,'\nTotal running time: %g seconds\n',time_value)
-    if(fn!="") fprintf('\nTotal running time: %g seconds\n',time_value)
-    #}
+    if(!is.null(time_value)){
+      fprintf(fn,'\nTotal running time: %g seconds\n',time_value)
+      if(fn!="") fprintf('\nTotal running time: %g seconds\n',time_value)
+    }
   } # end footer_flag
   if(!any(class(out_file)=="file") && (fn != '')) close(fn)
-  
-  return(invisible() ) 
+  return(invisible(time_value)) 
 }
 
 print_xt <- function (xtopt, ni, model_switch,fn="",head_txt="Optimized xt values:\n",xt_other=NULL) {
@@ -165,8 +189,8 @@ print_xt <- function (xtopt, ni, model_switch,fn="",head_txt="Optimized xt value
     for(i in unique(as.vector(model_switch_i))){
       xtopt_i_sort = sort(xtopt_i[model_switch_i==i])
       if(!is.null(xt_other)) xt_other_i_sort = xt_other_i[order(xtopt_i[model_switch_i==i])]
-      if(length(unique(as.vector(model_switch_i)))>1) cat(sprintf("Model %g : ", i),file=fn)
       if(size(xtopt,1)>1) cat(sprintf("Group %g : ", j),file=fn)
+      if(length(unique(as.vector(model_switch_i)))>1) cat(sprintf("Model %g : ", i),file=fn)
       if(!is.null(xt_other)) {
         cat(sprintf("%6.4g", xt_other_i_sort),file=fn)
       } else {
