@@ -15,7 +15,12 @@ m3 <- function(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,d,sigma,docc,bUseVarS
   
   ns=size(xt_ind,1)^2
   
-  dv_db_new=zeros(ns,sum(poped.db$parameters$notfixed_d)+sum(poped.db$parameters$notfixed_covd)+sum(poped.db$parameters$notfixed_docc)+sum(poped.db$parameters$notfixed_covdocc)+sum(poped.db$parameters$notfixed_sigma)+sum(poped.db$parameters$notfixed_covsigma))
+  dv_db_new=zeros(ns,sum(poped.db$parameters$notfixed_d)+
+                    sum(poped.db$parameters$notfixed_covd)+
+                    sum(poped.db$parameters$notfixed_docc)+
+                    sum(poped.db$parameters$notfixed_covdocc)+
+                    sum(poped.db$parameters$notfixed_sigma)+
+                    sum(poped.db$parameters$notfixed_covsigma))
   
   if((poped.db$settings$m2_switch[1] == 30) ){#Automatic differentiation of M3 dosen't work with ud variance term
     returnArgs <- LinMatrixL(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,poped.db) 
@@ -133,79 +138,79 @@ m3 <- function(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,d,sigma,docc,bUseVarS
     ret=dv_db_new
     
   } else { #If complex or central differentiation
-    
     k=1
-    
-    for(i in 1:poped.db$parameters$NumRanEff){
-      if((poped.db$parameters$notfixed_d[i]==1)){
-        d_plus=d
-        
-        # Central approximation
-        d_plus[i,i]=d_plus[i,i]+poped.db$settings$hm2
-        d_minus=d
-        d_minus[i,i]=d_minus[i,i]-poped.db$settings$hm2
-        
-        if((poped.db$settings$bCalculateEBE)){
-          start_bind = t(b_ind)%*%zeros(size(t(b_ind)))%*%t(b_ind)
-          b_ind_plus = ind_estimates(poped.db$mean_data,bpop,d_plus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
-          b_ind_minus = ind_estimates(poped.db$mean_data,bpop,d_minus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
-          # b_ind_plus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d+poped.db$settings$hm2))
-          # b_ind_minus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d-poped.db$settings$hm2))
-          #b_ind_plus = b_ind
-          #b_ind_minus = b_ind
-        } else {
-          b_ind_plus = b_ind
-          b_ind_minus = b_ind
+    if(!isempty(d)){
+      for(i in 1:poped.db$parameters$NumRanEff){
+        if((poped.db$parameters$notfixed_d[i]==1)){
+          d_plus=d
+          
+          # Central approximation
+          d_plus[i,i]=d_plus[i,i]+poped.db$settings$hm2
+          d_minus=d
+          d_minus[i,i]=d_minus[i,i]-poped.db$settings$hm2
+          
+          if((poped.db$settings$bCalculateEBE)){
+            start_bind = t(b_ind)%*%zeros(size(t(b_ind)))%*%t(b_ind)
+            b_ind_plus = ind_estimates(poped.db$mean_data,bpop,d_plus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
+            b_ind_minus = ind_estimates(poped.db$mean_data,bpop,d_minus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
+            # b_ind_plus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d+poped.db$settings$hm2))
+            # b_ind_minus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d-poped.db$settings$hm2))
+            #b_ind_plus = b_ind
+            #b_ind_minus = b_ind
+          } else {
+            b_ind_plus = b_ind
+            b_ind_minus = b_ind
+          }
+          
+          returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_plus,bocc_ind,d_plus,sigma,docc,poped.db) 
+          v_plus <- returnArgs[[1]]
+          poped.db <- returnArgs[[2]]
+          returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_minus,bocc_ind,d_minus,sigma,docc,poped.db) 
+          v_minus <- returnArgs[[1]]
+          poped.db <- returnArgs[[2]]
+          dv=v_plus-v_minus
+          if((!isempty(dv))){
+            ir=dv/(2*poped.db$settings$hm2)
+            ir=reshape_matlab(ir,ns,1)
+            dv_db_new[,k]=ir
+          }
+          k=k+1
         }
-        
-        returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_plus,bocc_ind,d_plus,sigma,docc,poped.db) 
-        v_plus <- returnArgs[[1]]
-        poped.db <- returnArgs[[2]]
-        returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_minus,bocc_ind,d_minus,sigma,docc,poped.db) 
-        v_minus <- returnArgs[[1]]
-        poped.db <- returnArgs[[2]]
-        dv=v_plus-v_minus
-        if((!isempty(dv))){
-          ir=dv/(2*poped.db$settings$hm2)
-          ir=reshape_matlab(ir,ns,1)
-          dv_db_new[,k]=ir
+      }  
+      
+      for(i in 1:length(poped.db$parameters$notfixed_covd)){
+        if((poped.db$parameters$notfixed_covd[i]==1)){
+          
+          d_plus=update_offdiag(d,i,poped.db$settings$hm2)
+          d_minus=update_offdiag(d,i,-poped.db$settings$hm2)
+          
+          if((poped.db$settings$bCalculateEBE)){
+            start_bind = t(b_ind)%*%zeros(size(t(b_ind)))%*% t(b_ind)
+            b_ind_plus = ind_estimates(poped.db$mean_data,bpop,d_plus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
+            b_ind_minus = ind_estimates(poped.db$mean_data,bpop,d_minus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
+            # b_ind_plus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d+poped.db$settings$hm2))
+            # b_ind_minus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d-poped.db$settings$hm2))
+            #b_ind_plus = b_ind
+            #b_ind_minus = b_ind
+          } else {
+            b_ind_plus = b_ind
+            b_ind_minus = b_ind
+          }
+          
+          returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_plus,bocc_ind,d_plus,sigma,docc,poped.db) 
+          v_plus <- returnArgs[[1]]
+          poped.db <- returnArgs[[2]]
+          returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_minus,bocc_ind,d_minus,sigma,docc,poped.db) 
+          v_minus <- returnArgs[[1]]
+          poped.db <- returnArgs[[2]]
+          dv=v_plus-v_minus
+          if((!isempty(dv))){
+            ir=dv/(2*poped.db$settings$hm2)
+            ir=reshape_matlab(ir,ns,1)
+            dv_db_new[,k]=ir
+          }
+          k=k+1
         }
-        k=k+1
-      }
-    }
-    
-    for(i in 1:length(poped.db$parameters$notfixed_covd)){
-      if((poped.db$parameters$notfixed_covd[i]==1)){
-        
-        d_plus=update_offdiag(d,i,poped.db$settings$hm2)
-        d_minus=update_offdiag(d,i,-poped.db$settings$hm2)
-        
-        if((poped.db$settings$bCalculateEBE)){
-          start_bind = t(b_ind)%*%zeros(size(t(b_ind)))%*% t(b_ind)
-          b_ind_plus = ind_estimates(poped.db$mean_data,bpop,d_plus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
-          b_ind_minus = ind_estimates(poped.db$mean_data,bpop,d_minus,sigma,start_bind,(poped.db$settings$iApproximationMethod==2),FALSE,model_switch,xt_ind,x,a,b_ind,bocc_ind,poped.db)
-          # b_ind_plus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d+poped.db$settings$hm2))
-          # b_ind_minus = b_ind/sqrt(diag_matlab(d))*sqrt(diag_matlab(d-poped.db$settings$hm2))
-          #b_ind_plus = b_ind
-          #b_ind_minus = b_ind
-        } else {
-          b_ind_plus = b_ind
-          b_ind_minus = b_ind
-        }
-        
-        returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_plus,bocc_ind,d_plus,sigma,docc,poped.db) 
-        v_plus <- returnArgs[[1]]
-        poped.db <- returnArgs[[2]]
-        returnArgs <- v(model_switch,xt_ind,x,a,bpop,b_ind_minus,bocc_ind,d_minus,sigma,docc,poped.db) 
-        v_minus <- returnArgs[[1]]
-        poped.db <- returnArgs[[2]]
-        dv=v_plus-v_minus
-        if((!isempty(dv))){
-          ir=dv/(2*poped.db$settings$hm2)
-          ir=reshape_matlab(ir,ns,1)
-          dv_db_new[,k]=ir
-        }
-        k=k+1
       }
     }
     
