@@ -1,21 +1,5 @@
 library(PopED)
 
-# This option is used to make this script run fast but without convergence 
-# (fast means a few seconds for each argument at the most).
-# This allows you to "source" this file and easily see how things work
-# without waiting for more than 10-30 seconds.
-# Change to FALSE if you want to run each function so that
-# the solutions have converged (can take many minutes).
-fast <- TRUE 
-
-iNumSimulations <- ifelse(fast,5,100)
-EAStepSize <- ifelse(fast,40,1)
-rsit <- ifelse(fast,3,300)
-sgit <- ifelse(fast,3,150)
-ls_step_size <- ifelse(fast,3,50)
-iter_max <- ifelse(fast,1,10)
-
-
 ##-- Model: One comp first order absorption
 ## -- Analytic solution for both mutiple and single dosing
 ff <- function(model_switch,xt,parameters,poped.db){
@@ -54,9 +38,9 @@ feps <- function(model_switch,xt,parameters,epsi,poped.db){
 }
 
 ## -- Define design and design space
-poped.db <- create.poped.database(ff_file="ff",
-                                  fg_file="sfg",
-                                  fError_file="feps",
+poped.db <- create.poped.database(ff_fun="ff",
+                                  fg_fun="sfg",
+                                  fError_fun="feps",
                                   bpop=c(V=72.8,KA=0.25,CL=3.75,Favail=0.9), 
                                   notfixed_bpop=c(1,1,1,0),
                                   d=c(V=0.09,KA=0.09,CL=0.25^2), 
@@ -68,43 +52,45 @@ poped.db <- create.poped.database(ff_file="ff",
                                   minxt=c(0,0,0,240,240),
                                   maxxt=c(10,10,10,248,248),
                                   bUseGrouped_xt=1,
-                                  a=cbind(c(20,40),c(24,24)),
-                                  maxa=c(200,24),
-                                  mina=c(0,24))
+                                  a=list(c(DOSE=20,TAU=24),c(DOSE=40, TAU=24)),
+                                  maxa=c(DOSE=200,TAU=24),
+                                  mina=c(DOSE=0,TAU=24))
 
 ##  create plot of model without variability 
-plot_model_prediction(poped.db)
+plot_model_prediction(poped.db, model_num_points = 300)
 
 ##  create plot of model with variability 
-plot_model_prediction(poped.db,IPRED=T,DV=T,separate.groups=T)
+plot_model_prediction(poped.db, IPRED=T, DV=T, separate.groups=T, model_num_points = 300)
 
 ## evaluate initial design
-FIM <- evaluate.fim(poped.db) 
-FIM
-det(FIM)
-get_rse(FIM,poped.db)
+evaluate_design(poped.db)
 
-# RS+SG+LS optimization of sample times
-output <- poped_optimize(poped.db,opt_xt=T,
-                         rsit=rsit,sgit=sgit,ls_step_size=ls_step_size,
-                         iter_max=iter_max)
-get_rse(output$fmf,output$poped.db)
+# Optimization of sample times
+output <- poped_optim(poped.db, opt_xt =TRUE, parallel=TRUE)
+
+# Evaluate optimization results
+summary(output)
+get_rse(output$FIM,output$poped.db)
 plot_model_prediction(output$poped.db)
 
-# RS+SG+LS optimization of sample times and doses
-output <- poped_optimize(poped.db,opt_xt=T,opt_a=T,
-                         rsit=rsit,sgit=sgit,ls_step_size=ls_step_size,
-                         iter_max=iter_max)
-get_rse(output$fmf,output$poped.db)
-plot_model_prediction(output$poped.db)
+# Optimization of sample times and doses
+output_2 <- poped_optim(output$poped.db, opt_xt =TRUE, opt_a = TRUE, parallel = TRUE)
+
+summary(output_2)
+get_rse(output_2$FIM,output_2$poped.db)
+plot_model_prediction(output_2$poped.db)
+
+# Optimization of sample times with only integer time points in design space
+# faster than continuous optimization in this case
+poped.db.discrete <- create.poped.database(poped.db,discrete_xt = list(0:248))
+
+output_discrete <- poped_optim(poped.db.discrete, opt_xt=T, parallel = TRUE)
+
+
+summary(output_discrete)
+get_rse(output_discrete$FIM,output_discrete$poped.db)
+plot_model_prediction(output_discrete$poped.db)
 
-# MFEA optimization with only integers (or multiples of 40 if fast=TRUE) in xt allowed (or original design)
-# faster optimization than RS+SG+LS in this case
-mfea.output <- poped_optimize(poped.db,opt_xt=T,
-                              bUseExchangeAlgorithm=1,
-                              EAStepSize=EAStepSize)
-get_rse(mfea.output$fmf,mfea.output$poped.db)
-plot_model_prediction(mfea.output$poped.db)
 
 # Efficiency of sampling windows
-plot_efficiency_of_windows(mfea.output$poped.db,xt_windows=1,iNumSimulations=iNumSimulations)
+plot_efficiency_of_windows(output_discrete$poped.db, xt_windows=1)
